Description Usage Examples
View source: R/utils.r
Initialize the current folder with the default working three of morexams Tutorial files are also copied in the working folder.
1
morexams_init()
1 2
library(morexams) morexams_init()
Add the following code to your website.
REMOVE THIS Copy to clipboard
For more information on customizing the embed code, read Embedding Snippets.